Hint: Use C-x t to copy tagged file names to the command line.

Hint: Use C-x p to copy the current pathname to the command line.

Hint: Completion: use M-Tab (or Esc+Tab).  Type it twice to get a list.

Hint: Use M-p and M-n to access the command history.

Hint: Need to quote a character? Use Control-q and the character.

Hint: Tired of these messages? Turn them off from the Options/Layout menu.

Hint: Selecting directories: add a slash to the end of the matching pattern.

Hint: If your terminal lacks functions keys, use the ESC+number sequence.

Hint: The homepage of GNU Midnight Commander:
http://www.midnight-commander.org/

Hint: Please send any bug reports to mc-devel@gnome.org

Hint: Tab changes your current panel.

Hint: VFS coolness: tap enter on a tar file to examine its contents.

Hint: We also have a nice manual page.

Hint: Do you want Lynx-style navigation? Set it in the Configuration dialog.

Hint: % macros work even on the command line.

Hint: M-! will allow you to execute programs and see the output in the
viewer.

Hint: The file listing format can be customized; do "man mc" for details.

Hint: %D/%T expands to the tagged files in the opposite directory.

Hint: Want your plain shell? Press C-o, and get back to MC with C-o again.

Hint: Setting the CDPATH variable can save you keystrokes in cd commands.

Hint: If you want to see your .* files, say so in the Configuration dialog.

Hint: Want to see your *~ backup files? Set it in the Configuration dialog.

Hint: Completion works on all input lines in all dialogs. Just press M-Tab.

Hint: On slow terminals the -s flag may help.

Hint: Find File: you can work on the files found using the Panelize button.

Hint: Want to do complex searches? Use the External Panelize command.

Hint: To change directory halfway through typing a command, use M-c (quick
cd).

Note: Shell commands will not work when you are on a non-local file system.

Hint: Bring text back from the dead with C-y.

Hint: Are some of your keys not working? Look at Options/Learn keys.

Hint: To look at the output of a command in the viewer, use M-!

Hint: F13 (or Shift-F3) invokes the viewer in raw mode.

Hint: You may specify the editor for F4 with the shell variable EDITOR.

Hint: You may specify the external viewer with the shell vars VIEWER or
PAGER.

Hint: You can disable all requests for confirmation in Options/Confirmation.

Hint: Leap to frequently used directories in a single bound with C-.

Hint: You can do anonymous FTP with mc by typing 'cd ftp://machine.edu'

Hint: FTP is built in the Midnight Commander, check the File/FTP link menu.

Hint: M-t changes quickly the listing mode.

Hint: You can specify the username when doing ftps: 'cd
ftp://user@machine.edu'

Hint: You can browse RPM files by tapping enter on top of an rpm file.

Hint: To mark directories on the select dialog box, append a slash.

Hint: To use the mouse cut and paste may require holding the shift key

Hint: Key frequently visited ftp sites in the hotlist: type C-.

